@@ -40,6 +40,7 @@ Note:
 """
 
 import argparse
+import logging
 from collections import OrderedDict
 from pathlib import Path
 from tempfile import TemporaryDirectory
@@ -58,8 +59,8 @@ from torchvision.datasets.utils import download_and_extract_archive
 
 import pytorch_lightning as pl
 from pl_examples import cli_lightning_logo
-from pytorch_lightning import _logger as log
 
+log = logging.getLogger(__name__)
 BN_TYPES = (torch.nn.BatchNorm1d, torch.nn.BatchNorm2d, torch.nn.BatchNorm3d)
 DATA_URL = "https://storage.googleapis.com/mledu-datasets/cats_and_dogs_filtered.zip"
 
