@@ -198,48 +198,56 @@ class AttributeDict(Dict):
         return out
 
 
+def lightning_get_all_attr_holders(model, attribute):
+    """ Special attribute finding for lightning.  Gets all of the objects or dicts that holds attribute.
+            Checks for attribute in model namespace, the old hparams namespace/dict, and the datamodule. """
+    trainer = getattr(model, 'trainer', None)
+
+    holders = []
+
+    # Check if attribute in model
+    if hasattr(model, attribute):
+        holders.append(model)
+
+    # Check if attribute in model.hparams, either namespace or dict
+    if hasattr(model, 'hparams'):
+        if attribute in model.hparams:
+            holders.append(model.hparams)
+
+    # Check if the attribute in datamodule (datamodule gets registered in Trainer)
+    if trainer is not None and trainer.datamodule is not None and hasattr(trainer.datamodule, attribute):
+        holders.append(trainer.datamodule)
+
+    return holders
+
+
+def lightning_get_first_attr_holder(model, attribute):
+    """ Special attribute finding for lightning.  Gets the object or dict that holds attribute, or None. Checks for attribute in model namespace,
+            the old hparams namespace/dict, and the datamodule, returns the last one that has it. """
+    holders = lightning_get_all_attr_holders(model, attribute)
+    if len(holders) == 0:
+        return None
+    # using the last holder to preserve backwards compatibility
+    return holders[-1]
+
+
 def lightning_hasattr(model, attribute):
     """ Special hasattr for lightning. Checks for attribute in model namespace,
         the old hparams namespace/dict, and the datamodule. """
-    trainer = getattr(model, 'trainer', None)
-
-    attr = False
-    # Check if attribute in model
-    if hasattr(model, attribute):
-        attr = True
-    # Check if attribute in model.hparams, either namespace or dict
-    elif hasattr(model, 'hparams'):
-        if isinstance(model.hparams, dict):
-            attr = attribute in model.hparams
-        else:
-            attr = hasattr(model.hparams, attribute)
-    # Check if the attribute in datamodule (datamodule gets registered in Trainer)
-    if not attr and trainer is not None:
-        attr = hasattr(trainer.datamodule, attribute)
-
-    return attr
+    return lightning_get_first_attr_holder(model, attribute) is not None
 
 
 def lightning_getattr(model, attribute):
     """ Special getattr for lightning. Checks for attribute in model namespace,
         the old hparams namespace/dict, and the datamodule. """
-    trainer = getattr(model, 'trainer', None)
-
-    # Check if attribute in model
-    if hasattr(model, attribute):
-        attr = getattr(model, attribute)
-    # Check if attribute in model.hparams, either namespace or dict
-    elif hasattr(model, 'hparams') and isinstance(model.hparams, dict) and attribute in model.hparams:
-        attr = model.hparams[attribute]
-    elif hasattr(model, 'hparams') and hasattr(model.hparams, attribute):
-        attr = getattr(model.hparams, attribute)
-    # Check if the attribute in datamodule (datamodule gets registered in Trainer)
-    elif trainer is not None and trainer.datamodule is not None and hasattr(trainer.datamodule, attribute):
-        attr = getattr(trainer.datamodule, attribute)
-    else:
+    holder = lightning_get_first_attr_holder(model, attribute)
+    if holder is None:
         raise ValueError(f'{attribute} is neither stored in the model namespace'
                          ' nor the `hparams` namespace/dict, nor the datamodule.')
-    return attr
+
+    if isinstance(holder, dict):
+        return holder[attribute]
+    return getattr(holder, attribute)
 
 
 def lightning_setattr(model, attribute, value):
@@ -247,23 +255,13 @@ def lightning_setattr(model, attribute, value):
         and the old hparams namespace/dict.
         Will also set the attribute on datamodule, if it exists.
     """
-    if not lightning_hasattr(model, attribute):
+    holders = lightning_get_all_attr_holders(model, attribute)
+    if len(holders) == 0:
         raise ValueError(f'{attribute} is neither stored in the model namespace'
                          ' nor the `hparams` namespace/dict, nor the datamodule.')
 
-    trainer = getattr(model, 'trainer', None)
-
-    # Check if attribute in model
-    if hasattr(model, attribute):
-        setattr(model, attribute, value)
-
-    # Check if attribute in model.hparams, either namespace or dict
-    elif hasattr(model, 'hparams'):
-        if isinstance(model.hparams, dict):
-            model.hparams[attribute] = value
+    for holder in holders:
+        if isinstance(holder, dict):
+            holder[attribute] = value
         else:
-            setattr(model.hparams, attribute, value)
-
-    # Check if the attribute in datamodule (datamodule gets registered in Trainer)
-    if trainer is not None and trainer.datamodule is not None and hasattr(trainer.datamodule, attribute):
-        setattr(trainer.datamodule, attribute, value)
+            setattr(holder, attribute, value)
